### Name: blasso
### Title: Bayesian Lasso Regression
### Aliases: blasso
### Keywords: regression

### ** Examples

## following the lars diabetes example
data(diabetes)
attach(diabetes)

## Ordinary Least Squares regression
reg.ols <- regress(x, y)

## Lasso regression
reg.las <- regress(x, y, method="lasso")

## Bayesian Lasso regression
reg.blas <- blasso(x, y, T=1000)

## summarize the beta (regression coefficients) estimates
plot(reg.blas, burnin=200)
points(drop(reg.las$b), col=2, pch=20)
points(drop(reg.ols$b), col=3, pch=18)
legend("topleft", c("lasso", "lsr"), col=2:3, pch=c(20,18))

## plot the size of different models visited
plot(reg.blas, burnin=200, which="m")

## (TODO: allow Bayes method with fixed lambda)

## get the summary
s <- summary(reg.blas)

## calculate the probability that each beta coef != zero
s$bn0

## summarize s2
plot(reg.blas, burnin=200, which="s2")
s$s2

## summarize lambda2
plot(reg.blas, burnin=200, which="lambda2")
s$lambda2

## clean up
detach(diabetes)

##
## a big-p small-n example
##

xmuS <- randmvn(50, 101)
X <- xmuS$x[,1:100]
y <- drop(xmuS$x[,101])
out.b <- blasso(X, y, T=1000, thin=20, verb=0)

## plot summary of the model order
plot(out.b, burnin=100, which="m")

## fit a standard lasso model
out.las <- regress(X, y, method="lasso")

## compare via RMSE
beta <- xmuS$S[101,-101] 
sqrt(mean((apply(out.b$beta, 2, mean) - beta)^2))
sqrt(mean((out.las$b[-1] - beta)^2))




